# AnyObjectConvertible
[![Build Status](https://travis-ci.org/tarunon/AnyObjectConvertible.svg?branch=master)](https://travis-ci.org/tarunon/AnyObjectConvertible)
[![Carthage compatible](https://img.shields.io/badge/Carthage-compatible-4BC51D.svg?style=flat)](https://github.com/Carthage/Carthage)
Convert your own struct/enum to AnyObject easily.

## Sumally 
In swift, struct or enum cannot convert to AnyObject
```swift
NSNotificationCenter.defaultCenter().postNotificationName("foo", object: YourOwnStruct()) // Fail
```
Of course, you may wrap value using Box\<T\>.
```swift
class Box<T> {
  let value: T
  init(value: T) {
    self.value = value
  }
}
NSNotificationCenter.defaultCenter().postNotificationName("foo", object: Box(value: YourOwnStruct())) // OK
```

But Box\<T\> unwrap is too lazy.
```swift
let value = (notification.object as? Box<YourOwnStruct>)?.value
```

You can cast your struct/enum directory if implement AnyObjectConvertible at that type.
```swift
extension YourOwnStruct: AnyObjectConvertible {}

NSNotificationCenter.defaultCenter().postNotificationName("foo", object: YourOwnStruct()) // OK
let value = notification.object as? YourOwnStruct
```

## Installation
Use Carthage.
```ruby
github "tarunon/AnyObjectConvertible"
```

## License
MIT
